@@ -161,8 +161,6 @@ RUN_ENVS = {
         'pip(){ ${pipdir}/bin/pip "$@"; }  # To avoid any local pip installations',
         ],
     'centos7-py36' :[
-        'alias xrdcp=$(which xrdcp)',
-        'alias gfal-copy=$(which gfal-copy)',
         'source /cvmfs/sft.cern.ch/lcg/views/LCG_96python3/x86_64-centos7-gcc8-opt/setup.sh',
         ]
     }
@@ -379,7 +377,6 @@ class Session(object):
         n_jobs_summed = sum([ njobs for _, njobs in self.submittables ])
         n_jobs_total = min(n_jobs_summed, njobsmax)
         logger.info('Submitting all jobs; %s out of %s', n_jobs_total, n_jobs_summed)
-        schedd = qondor.schedd.get_best_schedd()
         n_jobs_todo = n_jobs_total
         # Compile the .jdl file
         get_cluster_nr = lambda sub: sub['environment']['QONDORICLUSTER']
@@ -421,6 +418,7 @@ class Session(object):
             # with a while-loop and careful counting
             submittables = iter(self.submittables)
             for njobs_submitted, cluster_id in matches:
+                njobs_submitted = int(njobs_submitted)
                 logger.info('Submitted %s jobs to cluster_id %s', njobs_submitted, cluster_id)
                 njobs_assigned = 0
                 while njobs_assigned < njobs_submitted:
@@ -510,7 +508,17 @@ class Cluster(object):
         # Process pip packages
         self.pips = []
         pips = [] if pips is None else pips
-        for pip in [('qondor', 'auto'), ('seutils', 'auto')] + pips:
+        def check_if_in_pips(package):
+            """Checks if a package is already in the list"""
+            package, _ = qondor.utils.pip_split_version(package)
+            for pip in pips:
+                if not qondor.utils.is_string(pip): pip = pip[0]
+                pip, _ = qondor.utils.pip_split_version(pip)
+                if pip == package: return True
+            return False
+        if not check_if_in_pips('qondor'): pips.append(('qondor', 'auto'))
+        if not check_if_in_pips('seutils'): pips.append(('seutils', 'auto'))
+        for pip in pips:
             if qondor.utils.is_string(pip):
                 self.pips.append((pip, 'auto'))
             else:
@@ -571,6 +579,7 @@ class Cluster(object):
             '',
             'export VO_CMS_SW_DIR=/cvmfs/cms.cern.ch/',
             'source /cvmfs/cms.cern.ch/cmsset_default.sh',
+            'env > bare_env.txt', # Save the environment before doing any other environment setup
             '',
             ]
         # Set the runtime environment (typically sourcing scripts to get the right python/gcc/ROOT/etc.)
@@ -593,30 +602,11 @@ class Cluster(object):
             ''
             ]
         # `pip install` the required pip packages for the job
-        def should_split_version(package):
-            for c in [ '<', '=', '>' ]:
-                if c in package:
-                    return True
-            return False
-        def split_version_stuff(package):
-            split_at_index = False
-            for c in [ '<', '=', '>' ]:
-                if c in package:
-                    index = package.index(c)
-                    if split_at_index is False or index < split_at_index:
-                        split_at_index = index
-            if split_at_index:
-                return package[:split_at_index], package[split_at_index:]
-            return False
         for package, install_instruction in self.pips:
-            package = package.rstrip('/')
-            if should_split_version(package):
-                install_instruction = 'pypi'
-                package_name, version_stuff = split_version_stuff(package)
-                package_name = package_name.replace('.', '-')
-                package = package_name + version_stuff
-            else:
-                package = package.replace('.', '-').rstrip('/')
+            package_name, version_stuff = qondor.utils.pip_split_version(package.rstrip('/'))
+            package_name = package_name.replace('.', '-')
+            package = package_name + version_stuff
+            if version_stuff: install_instruction = 'pypi' # Force download from pypi for a specific version
             if install_instruction == 'auto':
                 install_instruction = 'editable' if qondor.utils.dist_is_editable(package) else 'pypi'
             if install_instruction == 'editable':
